##  Subscribing and Unsubscribing in Bulk
In the inventory table view mode, you can subscribe to or add subscribers to multiple fact sheets in one go. To learn about table view and inline editing, see [Bulk Updating Data in Inventory Table View](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view?locale=en-US&state=PRODUCTION&version=CLOUD "Table View lets you view and edit multiple fact sheets in a spreadsheet-like format—perfect for scanning, comparing, and updating data quickly and efficiently.").
To subscribe in bulk, follow these steps:
  1. In the inventory, apply filters to narrow down to fact sheets that you need.
  2. Switch to table view by selecting the As Table icon located at the top right.
  3. At the top right of the table, click the eye icon to add more columns to the table.
  4. Add the subscription types and roles as columns to the table.
![Adding the Subscription Types and Roles as Columns to the Table.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274cb19c7a4410148482918f071af03e_LowRes.png)
Adding the Subscription Types and Roles as Columns to the Table.
  5. Click Edit at the top of the table.
  6. In the relevant subscription columns, provide emails of users against the concerned fact sheets.
  7. Click Save.


Similar to subscribing in bulk, you can also unsubscribe from multiple fact sheets simultaneously. Follow the same steps as detailed above, but instead of adding users' emails, remove the emails of those who need to be unsubscribed.
Bulk subscribing and unsubscribing are also possible by importing data through Excel files. To learn more, see [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.").
